@@ -5,6 +5,7 @@
 */
 
 #include "grantleeeditor-version.h"
+
 #include "themeeditormainwindow.h"
 #include <KAboutData>
 #include <KCrash>
@@ -13,19 +14,20 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QIcon>
+using namespace Qt::Literals::StringLiterals;
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    app.setDesktopFileName(QStringLiteral("org.kde.contactprintthemeeditor"));
+    app.setDesktopFileName(u"org.kde.contactprintthemeeditor"_s);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("contactprintthemeeditor"));
-    KAboutData aboutData(QStringLiteral("contactprintthemeeditor"),
+    KAboutData aboutData(u"contactprintthemeeditor"_s,
                          i18n("Contact Print Theme Editor"),
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
                          i18n("Contact Print Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2015-%1 contactprintthemeeditor authors", QStringLiteral("2025")));
-    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kaddressbook")));
+                         i18n("Copyright © 2015-%1 contactprintthemeeditor authors", u"2025"_s));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), u"montel@kde.org"_s);
+    QApplication::setWindowIcon(QIcon::fromTheme(u"kaddressbook"_s));
     aboutData.setProductName(QByteArray("contactprintthemeeditor"));
 
     KAboutData::setApplicationData(aboutData);
